@@ -7,22 +7,21 @@
 from __future__ import division, print_function, absolute_import
 
 import random
-import warnings
 import functools
 
 import numpy as np
 from numpy import array, matrix, identity, dot, sqrt, double
-from numpy.testing import (TestCase, run_module_suite,
+from numpy.testing import (
         assert_array_equal, assert_array_less, assert_equal,
         assert_array_almost_equal, assert_array_almost_equal_nulp,
-        assert_allclose, assert_, decorators)
+        assert_allclose, assert_)
+import pytest
 
-from scipy._lib._numpy_compat import _assert_warns
+from scipy._lib._numpy_compat import _assert_warns, suppress_warnings
 
 import scipy.linalg
 from scipy.linalg import (funm, signm, logm, sqrtm, fractional_matrix_power,
         expm, expm_frechet, expm_cond, norm)
-from scipy.linalg.matfuncs import expm2, expm3
 from scipy.linalg import _matfuncs_inv_ssq
 import scipy.linalg._expm_frechet
 
@@ -50,7 +49,7 @@ def _get_al_mohy_higham_2012_experiment_1():
     return A
 
 
-class TestSignM(TestCase):
+class TestSignM(object):
 
     def test_nils(self):
         a = array([[29.2, -24.2, 69.5, 49.8, 7.],
@@ -93,7 +92,7 @@ class TestSignM(TestCase):
         #XXX: what would be the correct result?
 
 
-class TestLogM(TestCase):
+class TestLogM(object):
 
     def test_nils(self):
         a = array([[-2., 25., 0., 0., 0., 0., 0.],
@@ -193,7 +192,7 @@ class TestLogM(TestCase):
             w = scipy.linalg.eigvals(X)
             assert_(1e-2 < np.absolute(w.imag).sum())
             Y, info = logm(X, disp=False)
-            assert_(np.issubdtype(Y.dtype, dt))
+            assert_(np.issubdtype(Y.dtype, np.inexact))
             assert_allclose(expm(Y), X)
 
     def test_real_mixed_sign_spectrum(self):
@@ -205,7 +204,7 @@ class TestLogM(TestCase):
             for dt in float, complex:
                 A = np.array(M, dtype=dt)
                 A_logm, info = logm(A, disp=False)
-                assert_(np.issubdtype(A_logm.dtype, complex))
+                assert_(np.issubdtype(A_logm.dtype, np.complexfloating))
 
     def test_exactly_singular(self):
         A = np.array([[0, 0], [1j, 1j]])
@@ -239,7 +238,7 @@ class TestLogM(TestCase):
         assert_allclose(logm(E), L, atol=1e-14)
 
 
-class TestSqrtM(TestCase):
+class TestSqrtM(object):
     def test_round_trip_random_float(self):
         np.random.seed(1234)
         for n in range(1, 6):
@@ -395,7 +394,7 @@ class TestSqrtM(TestCase):
         assert_allclose(sqrtm(M), R, atol=1e-14)
 
 
-class TestFractionalMatrixPower(TestCase):
+class TestFractionalMatrixPower(object):
     def test_round_trip_random_complex(self):
         np.random.seed(1234)
         for p in range(1, 5):
@@ -553,7 +552,7 @@ class TestFractionalMatrixPower(TestCase):
                 A_power = fractional_matrix_power(A, p)
                 assert_(A_power.dtype.char in complex_dtype_chars)
 
-    @decorators.knownfailureif(True, 'Too unstable across LAPACKs.')
+    @pytest.mark.xfail(reason='Too unstable across LAPACKs.')
     def test_singular(self):
         # Negative fractional powers do not work with singular matrices.
         for matrix_as_list in (
@@ -580,31 +579,10 @@ class TestFractionalMatrixPower(TestCase):
         assert_allclose(fractional_matrix_power(M, 0.5), R, atol=1e-14)
 
 
-class TestExpM(TestCase):
+class TestExpM(object):
     def test_zero(self):
-        with warnings.catch_warnings():
-            warnings.simplefilter("ignore", DeprecationWarning)
-            a = array([[0.,0],[0,0]])
-            assert_array_almost_equal(expm(a),[[1,0],[0,1]])
-            assert_array_almost_equal(expm2(a),[[1,0],[0,1]])
-            assert_array_almost_equal(expm3(a),[[1,0],[0,1]])
-
-    def test_consistency(self):
-        with warnings.catch_warnings():
-            warnings.simplefilter("ignore", DeprecationWarning)
-            a = array([[0.,1],[-1,0]])
-            assert_array_almost_equal(expm(a), expm2(a))
-            assert_array_almost_equal(expm(a), expm3(a))
-
-            a = array([[1j,1],[-1,-2j]])
-            assert_array_almost_equal(expm(a), expm2(a))
-            assert_array_almost_equal(expm(a), expm3(a))
-
-    def test_npmatrix(self):
-        with warnings.catch_warnings():
-            warnings.simplefilter("ignore", DeprecationWarning)
-            a = matrix([[3.,0],[0,-3.]])
-            assert_array_almost_equal(expm(a), expm2(a))
+        a = array([[0.,0],[0,0]])
+        assert_array_almost_equal(expm(a),[[1,0],[0,1]])
 
     def test_single_elt(self):
         # See gh-5853
@@ -628,7 +606,7 @@ class TestExpM(TestCase):
                                               -0.84864425749518878))
 
 
-class TestExpmFrechet(TestCase):
+class TestExpmFrechet(object):
 
     def test_expm_frechet(self):
         # a test of the basic functionality
@@ -731,8 +709,8 @@ class TestExpmFrechet(TestCase):
         assert_allclose(sps_expm, blockEnlarge_expm)
         assert_allclose(sps_frechet, blockEnlarge_frechet)
 
-    @decorators.slow
-    @decorators.skipif(True, 'this test is deliberately slow')
+    @pytest.mark.slow
+    @pytest.mark.skip(reason='this test is deliberately slow')
     def test_medium_matrix(self):
         # profile this to see the speed difference
         n = 1000
@@ -765,7 +743,7 @@ def _relative_error(f, A, perturbation):
     return norm(X_prime - X) / norm(X)
 
 
-class TestExpmConditionNumber(TestCase):
+class TestExpmConditionNumber(object):
     def test_expm_cond_smoke(self):
         np.random.seed(1234)
         for n in range(1, 4):
@@ -795,7 +773,7 @@ class TestExpmConditionNumber(TestCase):
             A = np.random.randn(1, 1)
             assert_allclose(expm_cond(A), np.absolute(A)[0, 0])
 
-    @decorators.slow
+    @pytest.mark.slow
     def test_expm_cond_fuzz(self):
         np.random.seed(12345)
         eps = 1e-5
@@ -833,6 +811,3 @@ class TestExpmConditionNumber(TestCase):
             # In the limit as eps approaches zero it should never be greater.
             assert_array_less(p_best_relerr, (1 + 2*eps) * eps * kappa)
 
-
-if __name__ == "__main__":
-    run_module_suite()
